<?php
/*
 * Plugin Name: iStripper Banners Widget
 * Plugin URI: http://affiliates.istripper.com
 * Description: Easily display nice iStripper banners from the affiliate system via a Widget.
 * Version: 1.2.0
 * Author: iStripper
 * Author URI: http://affiliates.istripper.com
 * Author Email: webmaster@totemcash.com
 * Requires at least: 3.8
 * Tested up to: 3.9.1
 *
 * Text Domain: totemtools-banners-widget
 * Domain Path: languages
 * Network: false
 *
 * Copyright: (c) 2016 Totem Entertainment. (webmaster@totemcash.com)
 *
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 *
 * @package totemtools-banners-widget
 * @author iStripper
 * @category Core
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'TotemTools_Banners_Widget' ) ) {

/**
 * Main TotemTools Banners Widget Class
 *
 * @class TotemTools_Banners_Widget
 * @version 1.2.0
 */
final class TotemTools_Banners_Widget {

	// Slug
	const slug = 'totemtools_banners_widget';

	// Text Domain
	const text_domain = 'totemtools-banners-widget';

	/**
	 * The Plug-in name.
	 *
	 * @var string
	 */
	public $name = "iStripper Banners Widget";

	/**
	 * The Plug-in version.
	 *
	 * @var string
	 */
	public $version = "1.2.0";

	/**
	 * The WordPress version the plugin requires minumum.
	 *
	 * @var string
	 */
	public $wp_version_min = "3.8";

	/**
	 * The single instance of the class
	 *
	 * @var Plugin Name
	 */
	protected static $_instance = null;

	/**
	 * The Plug-in documentation URL.
	 *
	 * @var string
	 */
	public $doc_url = "https://affiliates.istripper.com/";

	/**
	 * Main VirtualGirl Banners Widget Instance
	 *
	 * Ensures only one instance of VirtualGirl Banners Widget is loaded or can be loaded.
	 *
	 * @access public static
	 * @see TotemTools_Banners_Widget()
	 * @return TotemTools Banners Widget - Main instance
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * Constructor
	 *
	 * @access public
	 */
	public function __construct() {
		// Define constants
		$this->define_constants();
		
		

		// Check plugin requirements
		$this->check_requirements();

		// Hooks
		add_filter( 'plugin_row_meta', array( &$this, 'plugin_row_meta' ), 10, 2 );
		add_action( 'widgets_init', array( &$this, 'include_widget' ) );
		add_action( 'init', array( &$this, 'init_affiliatewp_banners_widget' ), 0 );
	}

	/**
	 * Plugin row meta links
	 *
	 * @access public
	 * @param array $input already defined meta links
	 * @param string $file plugin file path and name being processed
	 * @return array $input
	 */
	public function plugin_row_meta( $input, $file ) {
		if ( plugin_basename( __FILE__ ) !== $file ) {
			return $input;
		}

		$links = array(
			'<a href="' . esc_url( $this->doc_url ) . '">' . __( 'Documentation', 'totemtools-banners-widget' ) . '</a>',
		);

		$input = array_merge( $input, $links );

		return $input;
	}

	/**
	 * Define Constants
	 *
	 * @access private
	 */
	private function define_constants() {
		define( 'TT_BANNERS_WIDGET', $this->name );
		define( 'TT_BANNERS_WIDGET_FILE', __FILE__ );
		define( 'TT_BANNERS_WIDGET_VERSION', $this->version );
		define( 'TT_BANNERS_WIDGET_WP_VERSION_REQUIRE', $this->wp_version_min );
		define( 'TT_BANNERS_WIDGET_PAGE', str_replace('_', '-', self::slug) );
		define( 'TT_BANNERS_URL', '//bnrs.it/r.php' );
	}

	/**
	 * Checks that the WordPress setup meets the plugin requirements.
	 *
	 * @access private
	 * @global string $wp_version
	 * @return boolean
	 */
	private function check_requirements() {
		global $wp_version;

		if (!version_compare($wp_version, TT_BANNERS_WIDGET_WP_VERSION_REQUIRE, '>=')) {
			add_action('admin_notices', array( &$this, 'display_req_notice' ) );
			return false;
		}

		return true;
	}

	/**
	 * Display the requirement notice.
	 *
	 * @access static
	 */
	static function display_req_notice() {
		echo '<div id="message" class="error"><p><strong>';
		echo sprintf( __('Sorry, %s requires WordPress ' . TT_BANNERS_WIDGET_WP_VERSION_REQUIRE . ' or higher. Please upgrade your WordPress setup', 'totemtools-banners-widget'), TT_BANNERS_WIDGET );
		echo '</strong></p></div>';
	}

	/**
	 * Include widget.
	 *
	 * @access public
	 * @return void
	 */
	public function include_widget() {
		include_once( 'includes/widget.php' );
	}

	/**
	 * Runs when the plugin is initialized.
	 *
	 * @access public
	 */
	public function init_affiliatewp_banners_widget() {
		// Set up localisation
		$this->load_plugin_textdomain();
	}

	/**
	 * Load Localisation files.
	 *
	 * Note: the first-loaded translation file overrides any 
	 * following ones if the same translation is present.
	 *
	 * @access public
	 * @return void
	 */
	public function load_plugin_textdomain() {
		// Set filter for plugin's languages directory
		$lang_dir = dirname( plugin_basename( TT_BANNERS_WIDGET_FILE ) ) . '/languages/';
		$lang_dir = apply_filters( 'totemtools_banners_widget_languages_directory', $lang_dir );

		// Traditional WordPress plugin locale filter
		$locale = apply_filters( 'plugin_locale',  get_locale(), self::text_domain );
		$mofile = sprintf( '%1$s-%2$s.mo', self::text_domain, $locale );

		// Setup paths to current locale file
		$mofile_local  = $lang_dir . $mofile;
		$mofile_global = WP_LANG_DIR . '/' . self::text_domain . '/' . $mofile;

		if ( file_exists( $mofile_global ) ) {
			// Look in global /wp-content/languages/totemtools-affiliate-banners-widget/ folder
			load_textdomain( self::text_domain, $mofile_global );
		}
		elseif ( file_exists( $mofile_local ) ) {
			// Look in local /wp-content/plugins/totemtools-affiliate-banners-widget/languages/ folder
			load_textdomain( self::text_domain, $mofile_local );
		}
		else {
			// Load the default language files
			load_plugin_textdomain( self::text_domain, false, $lang_dir );
		}
	}

	/** Helper functions ******************************************************/

	/**
	 * Get the plugin url.
	 *
	 * @access public
	 * @return string
	 */
	public function plugin_url() {
		return untrailingslashit( plugins_url( '/', __FILE__ ) );
	}

	/**
	 * Get the plugin path.
	 *
	 * @access public
	 * @return string
	 */
	public function plugin_path() {
		return untrailingslashit( plugin_dir_path( __FILE__ ) );
	}

} // end class

} // end if class exists

/**
 * Returns the main instance of AffiliateWP_Banners_Widget to prevent the need to use globals.
 *
 * @return Plugin Name
 */
function TotemTools_Banners_Widget() {
	return TotemTools_Banners_Widget::instance();
}

// Global for backwards compatibility.
$GLOBALS['totemtools-banners-widget'] = TotemTools_Banners_Widget();

?>